using Dto;
using Model;
using Shared;

namespace APIMappers;

public static class ActivityMapper
{
    private static GenericMapper<Activity, ActivityDto> _mapper = new();
    
    public static Activity ToModel(this ActivityDto activityDto)
    {
        Func<ActivityDto, Activity> create = activity => new Activity 
        {
            Id = activity.Id,
            Type = activity.Type,
            Date = activity.Date,
            StartTime = activity.StartTime,
            EndTime = activity.EndTime,
            Effort = activity.EffortFelt,
            Variability = activity.Variability,
            Variance = activity.Variance,
            StandardDeviation = activity.StandardDeviation,
            Average = activity.Average,
            Maximum = activity.Maximum,
            Minimum = activity.Minimum,
            AverageTemperature = activity.AverageTemperature,
            HasAutoPause = activity.HasAutoPause
        };

        Action<ActivityDto, Activity> link = (activity, model) =>
        {
            model.HeartRates.AddRange(activity.HeartRates.ToModels(activityDto.Id).ToArray());
            if (activity.DataSource != null) model.DataSource = activity.DataSource.ToModel();
            model.Athlete = activity.Athlete.ToModel();
        };

        return activityDto.ToT(_mapper, create, link);
    }
    
    public static ActivityDto ToDto(this Activity model)
    {
        Func<Activity, ActivityDto> create = activity => new ActivityDto
        {
            Id = activity.Id,
            Type = activity.Type,
            Date = activity.Date,
            StartTime = activity.StartTime,
            EndTime = activity.EndTime,
            EffortFelt = activity.Effort,
            Variability = activity.Variability,
            Variance = activity.Variance,
            StandardDeviation = activity.StandardDeviation,
            Average = activity.Average,
            Maximum = activity.Maximum,
            Minimum = activity.Minimum,
            AverageTemperature = activity.AverageTemperature,
            HasAutoPause = activity.HasAutoPause
        };
        
        Action<Activity, ActivityDto> link = (activity, dto) =>
        {
            dto.HeartRates = activity.HeartRates.ToDtos().ToArray();
            dto.DataSource = activity.DataSource.ToDto();
            dto.Athlete = activity.Athlete.ToDto();
        };
        
        return model.ToU(_mapper, create, link);
    }
    
    public static IEnumerable<Activity> ToModels(this IEnumerable<ActivityDto> dtos)
    => dtos.Select(dto => dto.ToModel());
    
    public static IEnumerable<ActivityDto> ToDtos(this IEnumerable<Activity> models)
    => models.Select(model => model.ToDto());
    
    
    

}